package org.jastadd.ragconnect.compiler;

import org.jastadd.ragconnect.ast.*;
import org.jastadd.ragconnect.parser.RagConnectParser;
import org.jastadd.ragconnect.scanner.RagConnectScanner;

import java.io.Reader;
import java.nio.file.Files;
import java.nio.file.Paths;

/**
 * Testing Ros2Rag without parser.
 *
 * @author rschoene - Initial contribution
 */
public class SimpleMain {

  private static void printManualYAML() {
    Document doc = new Document();
    MappingElement root = new MappingElement();
    MappingElement firstLevel = new MappingElement();
    firstLevel.addKeyValuePair(new KeyValuePair("server", new StringElement("tcp://localhost:1883")));
    firstLevel.addKeyValuePair(new KeyValuePair("robot_speed_factor", new ValueElement(".7")));

    KeyValuePair topics = new KeyValuePair();
    topics.setKey("topics");
    MappingElement theTopics = new MappingElement();
    theTopics.addKeyValuePair(new KeyValuePair("robotConfig", new StringElement("robotconfig")));
    theTopics.addKeyValuePair(new KeyValuePair("trajectory", new StringElement("trajectory")));
    theTopics.addKeyValuePair(new KeyValuePair("nextStep", new StringElement("ros2rag/nextStep")));
    topics.setValue(theTopics);
    firstLevel.addKeyValuePair(topics);

    firstLevel.addKeyValuePair(new KeyValuePair("zone_size", new ValueElement("0.5")));

    ListElement theZones = new ListElement();
    theZones.addElement(new StringElement("1 1"));
    theZones.addElement(new StringElement("0 1"));
    theZones.addElement(new StringElement("-1 1"));
    firstLevel.addKeyValuePair("zones", theZones);

    MappingElement pandaParts = new MappingElement();
    MappingElement thePanda = new MappingElement();
    thePanda.addKeyValuePair(new KeyValuePair("Link0", new StringElement("panda_link0")));
    thePanda.addKeyValuePair(new KeyValuePair("Link1", new StringElement("panda_link1")));
    thePanda.addKeyValuePair(new KeyValuePair("Link2", new StringElement("panda_link2")));
    thePanda.addKeyValuePair(new KeyValuePair("Link3", new StringElement("panda_link3")));
    thePanda.addKeyValuePair(new KeyValuePair("Link4", new StringElement("panda_link4")));
    thePanda.addKeyValuePair(new KeyValuePair("Link5", new StringElement("panda_link5")));
    thePanda.addKeyValuePair(new KeyValuePair("Link6", new StringElement("panda_link6")));
    thePanda.addKeyValuePair(new KeyValuePair("RightFinger", new StringElement("panda_rightfinger")));
    thePanda.addKeyValuePair(new KeyValuePair("LeftFinger", new StringElement("panda_leftfinger")));
    pandaParts.addKeyValuePair("panda", thePanda);
    firstLevel.addKeyValuePair("parts", pandaParts);

    MappingElement endEffectorParts = new MappingElement();
    MappingElement endEffector = new MappingElement();
    endEffector.addKeyValuePair("EndEffector", new StringElement("panda_hand"));
    endEffectorParts.addKeyValuePair("panda", endEffector);
    firstLevel.addKeyValuePair("end_effectors", endEffectorParts);

    KeyValuePair goalPoses = new KeyValuePair();
    goalPoses.setKey("goal_poses");
    ListElement theGoalPoses = new ListElement();
    addPose(theGoalPoses, "0.4 0.4 0.3");
    addPose(theGoalPoses, "-0.4 0.4 0.3");
    addPose(theGoalPoses, "-0.4 -0.4 0.3");
    addPose(theGoalPoses, "0.4 0.4 0.3");
    addPose(theGoalPoses, "-0.4 0.4 0.3");
    addPose(theGoalPoses, "0.4 0.4 0.3");
    goalPoses.setValue(theGoalPoses);
    firstLevel.addKeyValuePair(goalPoses);

    root.addKeyValuePair("panda_mqtt_connector", firstLevel);
    doc.setRootElement(root);

    System.out.println(doc.prettyPrint());
  }

  private static void addPose(ListElement theGoalPoses, String position) {
    MappingElement goalPose1 = new MappingElement();
    goalPose1.addKeyValuePair(new KeyValuePair("position", new StringElement(position)));
    goalPose1.addKeyValuePair(new KeyValuePair("orientation", new StringElement("1 1 0 0")));
    goalPose1.addKeyValuePair(new KeyValuePair("work", new StringElement("20000")));
    theGoalPoses.addElement(goalPose1);
  }

  public static void main(String[] args) {
    printManualYAML();
  }
}
